<?php

namespace Bixo\Aml\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Aml\Actions\NameAction;
use Bixo\Aml\Http\Requests\NameActionRequest;
use Bixo\Aml\Http\Resources\NameResource;
use Bixo\Aml\Models\Name;

/**
 * Admin web controller class.
 */
class NameActionController extends BaseController
{

    /**
     * Action controller function for name.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(NameActionRequest $request, Name $name, $action)
    {
        try {
            $request = $request->all();
            $name = NameAction::run($action, $name, $request);

            $data = new NameResource($name);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('aml::name.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('aml/name/' . $name->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('aml/name/' . $name->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
