<?php

namespace Bixo\Aml\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Aml\Http\Resources\AmlResource;
use Bixo\Aml\Http\Resources\AmlsCollection;
use Bixo\Aml\Scopes\NamePublicScope;
use Bixo\Aml\Models\Name;

class NamePublicController extends BaseController
{

    /**
     * Show name's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Name::pushScope(new RequestScope())
            ->pushScope(new NamePublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $names = new NamesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('aml::name.names'))
            ->view('aml::public.name.index')
            ->data(compact('names', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show name.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Name::findBySlug($slug);
        $data = new NameResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('aml::name.name'))
            ->view('aml::public.name.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
