<?php

namespace Bixo\Aml\Http\Controllers;

use Exception;
use Bixo\Aml\Actions\NameWorkflow;
use Bixo\Aml\Http\Requests\NameWorkflowRequest;
use Bixo\Aml\Http\Resources\NameResource;
use Bixo\Aml\Models\Name;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class NameWorkflowController extends BaseController
{
    /**
     * Action controller function for name.
     *
     * @param Model $name
     * @param action next action for the name.
     *
     * @return Response
     */
    public function __invoke(NameWorkflowRequest $request, Name $name, $trasition)
    {
        try {
            $request = $request->all();
            $name = NameWorkflow::run($trasition, $name, $request);
            $data = new NameResource($name);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('aml::name.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('aml/name/' . $name->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('aml/name/' . $name->getRouteKey()))
                ->redirect();
        }
    }


    /**
     * Get the name and user for the workflow.
     *
     * @param PublicRequest $request
     * @param string $name
     * @param string $user
     *
     * @return Response
     */
    public function get(PublicRequest $request, $name, $user)
    {
        if (!$request->hasValidSignature()) {
            abort(403, 'This url is expired!');
        }

        $auth = Auth::guard()->getProvider()->getModel();
        $user = $auth::findBySignedId($user);
        Auth::guard()->login($user);
        $name = Name::findBySignedId($name);
        $transitions = $this->transitions($name, $user);
        $user = user();
        Auth::logout();
        return $this->response->setMetaTitle(trans('aml::name.name') . ' ' . trans('Approvals'))
            ->view('aml::public.name.workflow')
            ->layout('mobile')
            ->data(compact('name', 'user', 'transitions'))
            ->output();
    }

    /**
     * Display the workflow form for the name.
     *
     * @param PublicRequest $request
     * @param string $name
     * @param string $user
     *
     * @return Response
     */
    public function post(PublicRequest $request, $name, $user)
    {
        if (!$request->hasValidSignature()) {
            abort(403, 'This url is expired!');
        }
        $transition = $request->transition;
        $auth = Auth::guard()->getProvider()->getModel();
        $user = $auth::findBySignedId($user);
        Auth::guard()->login($user);
        $name = Name::findBySignedId($name);
        $user = user();
        $name = NameWorkflow::run($transition, $name, $request->all());
        Auth::logout();

        return response()->json(
            [
                'status' => 'success',
                'url' => $request->url(),
            ]
        );
    }

    private function transitions($name, $user)
    {
        $transitions = [];
        foreach ($name->workflow()->transitions($name) as $key => $value) {
            $name = $value->getName();
            $array['url'] = URL::temporarySignedRoute('litecms.name.workflow', now()->addMinutes(3), [
                'guard' => 'admin',
                'transition' => $name,
                'name' => $name->getSignedId(now()->addMinutes(3)),
                'user' => $user->getSignedId(now()->addMinutes(3)),
                'trans' => 'en',
            ]
            );
            $array['name'] = $name;
            $array['key'] = $name;
            $array['form'] = $name->workflow()->form($value);
            $array['label'] = trans('aml::name.workflow.' . $name);
            $transitions[] = $array;
        }
        return $transitions;
    }
}
