<?php

namespace Bixo\Aml\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Aml\Actions\NationalityAction;
use Bixo\Aml\Http\Requests\NationalityActionRequest;
use Bixo\Aml\Http\Resources\NationalityResource;
use Bixo\Aml\Models\Nationality;

/**
 * Admin web controller class.
 */
class NationalityActionController extends BaseController
{

    /**
     * Action controller function for nationality.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(NationalityActionRequest $request, Nationality $nationality, $action)
    {
        try {
            $request = $request->all();
            $nationality = NationalityAction::run($action, $nationality, $request);

            $data = new NationalityResource($nationality);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('aml::nationality.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('aml/nationality/' . $nationality->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('aml/nationality/' . $nationality->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
