<?php

namespace Bixo\Aml\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Aml\Http\Resources\AmlResource;
use Bixo\Aml\Http\Resources\AmlsCollection;
use Bixo\Aml\Scopes\NationalityPublicScope;
use Bixo\Aml\Models\Nationality;

class NationalityPublicController extends BaseController
{

    /**
     * Show nationality's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Nationality::pushScope(new RequestScope())
            ->pushScope(new NationalityPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $nationalities = new NationalitiesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('aml::nationality.names'))
            ->view('aml::public.nationality.index')
            ->data(compact('nationalities', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show nationality.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Nationality::findBySlug($slug);
        $data = new NationalityResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('aml::nationality.name'))
            ->view('aml::public.nationality.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
