<?php

namespace Bixo\Aml\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Bixo\Aml\Forms\Sanction as SanctionForm;
use Bixo\Aml\Http\Requests\SanctionResourceRequest;
use Bixo\Aml\Http\Resources\SanctionResource;
use Bixo\Aml\Http\Resources\SanctionsCollection;
use Bixo\Aml\Models\Sanction;
use Bixo\Aml\Actions\SanctionAction;
use Bixo\Aml\Actions\SanctionActions;


/**
 * Resource controller class for sanction.
 */
class SanctionResourceController extends BaseController
{

    /**
     * Initialize sanction resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = SanctionForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('bixo.aml.modules'), 'aml', guard_url('aml'));
            return $next($request);
        });
    }

    /**
     * Display a list of sanction.
     *
     * @return Response
     */
    public function index(SanctionResourceRequest $request)
    {
        $request = $request->all();
        $page = SanctionActions::run('paginate', $request);

        $data = new SanctionsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('aml::sanction.names'))
            ->view('aml::sanction.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display sanction.
     *
     * @param Request $request
     * @param Model   $sanction
     *
     * @return Response
     */
    public function show(SanctionResourceRequest $request, Sanction $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new SanctionResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('aml::sanction.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('aml::sanction.show')
            ->output();
    }

    /**
     * Show the form for creating a new sanction.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(SanctionResourceRequest $request, Sanction $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new SanctionResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('aml::sanction.name'))
            ->view('aml::sanction.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new sanction.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SanctionResourceRequest $request, Sanction $model)
    {
        try {
            $request = $request->all();
            $model = SanctionAction::run('store', $model, $request);
            $data = new SanctionResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('aml::sanction.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('aml/sanction/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/aml/sanction'))
                ->redirect();
        }

    }

    /**
     * Show sanction for editing.
     *
     * @param Request $request
     * @param Model   $sanction
     *
     * @return Response
     */
    public function edit(SanctionResourceRequest $request, Sanction $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new SanctionResource($model);
        // return view('aml::sanction.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('aml::sanction.name'))
            ->view('aml::sanction.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the sanction.
     *
     * @param Request $request
     * @param Model   $sanction
     *
     * @return Response
     */
    public function update(SanctionResourceRequest $request, Sanction $model)
    {
        try {
            $request = $request->all();
            $model = SanctionAction::run('update', $model, $request);
            $data = new SanctionResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('aml::sanction.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('aml/sanction/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('aml/sanction/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the sanction.
     *
     * @param Model   $sanction
     *
     * @return Response
     */
    public function destroy(SanctionResourceRequest $request, Sanction $model)
    {
        try {

            $request = $request->all();
            $model = SanctionAction::run('destroy', $model, $request);
            $data = new SanctionResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('aml::sanction.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('aml/sanction/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('aml/sanction/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
