<?php

namespace Bixo\Aml\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Aml\Events\NameAction as NameActionEvent;
use Bixo\Aml\Notifications\NameAction as NameActionNotification;
use Litepie\Actions\Concerns\AsAction;

class NameAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the NameActionEvent.
     *
     * @param   NameActionEvent  $event
     * @return mixed
     */
    public function handle(NameActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $name.
     *
     * @param   NameActionEvent  $event
     * @return void
     */
    public function create(NameActionEvent $event)
    {
        $client = $event->name->client;
        Notification::send($client, new NameActionNotification($event));
    }

    /**
     * Handle the NameActionEvent as a listener.
     *
     * @param   NameActionEvent  $event
     * @return mixed
     */
    public function asListener(NameActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   NameActionEvent  $event
     * @return bool
     */
    private function isAllowed(NameActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
