<?php

namespace Bixo\Aml\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Aml\Events\NameWorkflow as NameWorkflowEvent;
use Bixo\Aml\Notifications\NameWorkflow as NameWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class NameWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(NameWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $name is submitted.
     *
     * @param NameWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(NameWorkflowEvent $event)
    {
        $client = $event->name->client;
        Notification::send($client, new NameWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $name is published.
     *
     * @param NameWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(NameWorkflowEvent $event)
    {
        $client = $event->name->client;
        Notification::send($client, new NameWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $name is approved.
     *
     * @param NameWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(NameWorkflowEvent $event)
    {
        $client = $event->name->client;
        Notification::send($client, new NameWorkflowNotification($event));
    }

    /**
     * Handles the $name workflow event as a listener.
     *
     * @param NameWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(NameWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
