<?php

namespace Bixo\Aml\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Aml\Events\NationalityWorkflow as NationalityWorkflowEvent;
use Bixo\Aml\Notifications\NationalityWorkflow as NationalityWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class NationalityWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(NationalityWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $nationality is submitted.
     *
     * @param NationalityWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(NationalityWorkflowEvent $event)
    {
        $client = $event->nationality->client;
        Notification::send($client, new NationalityWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $nationality is published.
     *
     * @param NationalityWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(NationalityWorkflowEvent $event)
    {
        $client = $event->nationality->client;
        Notification::send($client, new NationalityWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $nationality is approved.
     *
     * @param NationalityWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(NationalityWorkflowEvent $event)
    {
        $client = $event->nationality->client;
        Notification::send($client, new NationalityWorkflowNotification($event));
    }

    /**
     * Handles the $nationality workflow event as a listener.
     *
     * @param NationalityWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(NationalityWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
