<?php

namespace Bixo\Aml\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Aml\Events\SanctionAction as SanctionActionEvent;
use Bixo\Aml\Notifications\SanctionAction as SanctionActionNotification;
use Litepie\Actions\Concerns\AsAction;

class SanctionAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the SanctionActionEvent.
     *
     * @param   SanctionActionEvent  $event
     * @return mixed
     */
    public function handle(SanctionActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $sanction.
     *
     * @param   SanctionActionEvent  $event
     * @return void
     */
    public function create(SanctionActionEvent $event)
    {
        $client = $event->sanction->client;
        Notification::send($client, new SanctionActionNotification($event));
    }

    /**
     * Handle the SanctionActionEvent as a listener.
     *
     * @param   SanctionActionEvent  $event
     * @return mixed
     */
    public function asListener(SanctionActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   SanctionActionEvent  $event
     * @return bool
     */
    private function isAllowed(SanctionActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
