<?php

namespace Bixo\Aml\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Aml\Events\SanctionWorkflow as SanctionWorkflowEvent;
use Bixo\Aml\Notifications\SanctionWorkflow as SanctionWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class SanctionWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(SanctionWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $sanction is submitted.
     *
     * @param SanctionWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(SanctionWorkflowEvent $event)
    {
        $client = $event->sanction->client;
        Notification::send($client, new SanctionWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $sanction is published.
     *
     * @param SanctionWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(SanctionWorkflowEvent $event)
    {
        $client = $event->sanction->client;
        Notification::send($client, new SanctionWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $sanction is approved.
     *
     * @param SanctionWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(SanctionWorkflowEvent $event)
    {
        $client = $event->sanction->client;
        Notification::send($client, new SanctionWorkflowNotification($event));
    }

    /**
     * Handles the $sanction workflow event as a listener.
     *
     * @param SanctionWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(SanctionWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
