<?php

namespace Bixo\Aml\Providers;

use Illuminate\Support\ServiceProvider;
use Bixo\Aml\Amls;

class AmlServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'aml');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'aml');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Bixo\Aml\Providers\AuthServiceProvider::class);
        $this->app->register(\Bixo\Aml\Providers\RouteServiceProvider::class);
        $this->app->register(\Bixo\Aml\Providers\ActionServiceProvider::class);
        $this->app->register(\Bixo\Aml\Providers\EventServiceProvider::class);
        $this->app->register(\Bixo\Aml\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('bixo.aml', function($app)
        {
            return $this->app->make(Aml::class);
        });
    }

    /**
     * Merges user's and aml's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.aml'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/name.php', 'bixo.aml.name'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/nationality.php', 'bixo.aml.nationality'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/sanction.php', 'bixo.aml.sanction'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.aml'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('bixo/aml')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/aml')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/aml')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
